@@ -1,37 +1,47 @@
 from chargebeecli.client.actionsImpl import ActionsImpl
+from chargebeecli.constants.constants import Formats
 from chargebeecli.export.Exporter import Exporter
-from chargebeecli.processor import Processor
-from chargebeecli.response_formatter import ResponseFormatter
-from chargebeecli.validator import Validator
+from chargebeecli.formater.response_formatter import ResponseFormatter
+from chargebeecli.printer.printer import Printer
+from chargebeecli.processors.processor import Processor
+from chargebeecli.validator.validator import Validator
 
 API_URI = '/api/v2/gifts'
 
 
-class Gift(Processor, Validator, ResponseFormatter, Exporter):
+class Gift(Processor, Validator, ResponseFormatter, Exporter, Printer):
     __action_processor = ActionsImpl()
 
-    def __init__(self, export_format=None, export_path=None, file_name=None):
+    def __init__(self, export_format, export_path, file_name, response_format, _operation, _input_columns):
         self.headers = self.get_api_header()
         self.export_format = export_format
         self.export_path = export_path
         self.file_name = file_name
         self.tables = None
+        self.response_format = response_format
+        self.operation = _operation
+        self.input_columns = _input_columns
 
-    def validate_param(self, __input_columns):
-        self.headers = super().validate_param(__input_columns, self.headers)
+    def validate_param(self):
+        self.headers = super().validate_param(self.input_columns, self.headers)
         return self
 
     def get_api_header(self):
         return ["auto_claim", "claim_expiry_date", "gift_receiver", "gift_timelines", "gifter", "id", "no_expiry",
                 "object", "resource_version", "scheduled_at", "status", "updated_at"]
 
-    def format(self, __format, __operation):
-        super().format(self.response, __format, __operation, self.headers, 'gift', 'list')
-        return self
-
     def process(self, ctx, operation, payload, resource_id):
         return super(Gift, self).process(ctx, operation, payload, resource_id)
 
+    def to_be_formatted(self):
+        return self.response_format.lower() == Formats.TABLE.value
+
+    def format(self):
+        if self.to_be_formatted():
+            self.tables = super(Gift, self).format(self.response, self.response_format, self.operation,
+                                                   self.headers, 'gift', 'list')
+        return self
+
     def get(self, ctx, payload, resource_id):
         return self.__action_processor.get(API_URI + '/' + resource_id)
 
@@ -41,11 +51,5 @@ class Gift(Processor, Validator, ResponseFormatter, Exporter):
     def delete(self, ctx, payload, resource_id):
         return self.__action_processor.delete(API_URI + '/' + resource_id + '/' + 'cancel')
 
-
-    def to_be_exported(self):
-        return self.export_format and self.export_path and self.file_name
-
-    def export_data(self):
-        if self.to_be_exported():
-            Exporter(self.headers, self.tables).export(_path=self.export_path, _export_format=self.export_format,
-                                                       _file_name=self.file_name)
\ No newline at end of file
+    def table_to_be_printed(self):
+        return self.to_be_formatted()
